#ifndef BINARYPACKAGE_H_
#define BINARYPACKAGE_H_

#include "package.h"

/**
Represents a package that is installed on the system, but can't be built by
Builder.
*/
class BinaryPackage: public Package
{
public:
	class Loader: public Msp::DataFile::DerivedObjectLoader<BinaryPackage, Package::Loader>
	{
	public:
		Loader(BinaryPackage &);
	private:
		void build_info();
		void header(const std::string &);
	};

	typedef std::vector<std::string> Flags;

private:
	typedef std::list<std::string> HeaderList;

	Msp::FS::Path base_path;
	HeaderList headers;
	BuildInfo static_binfo;

public:
	BinaryPackage(Builder &, const std::string &);

	const BuildInfo &get_static_build_info() const { return static_binfo; }

	static BinaryPackage *from_flags(Builder &, const std::string &, const Flags &, const Flags & = Flags());
private:
	static void process_flags(const Flags &, BuildInfo &);
	virtual void do_prepare();
};

#endif
